import QtQuick 1.1
import "../imports/XAComponents"
import "../Map"

Item {
    id: maincomponent
    height: 49
    width: parent.width

    // 0 = Text
    // 1 = Date Picker
    // 2 = Context Selection
    // 3 = Security Picker
    // 4 = Repeat Picker
    property int lineInputType: 0
    property string contextInputType: ""

    property int inputInset: 12

    property bool itemShowLabel: true
    property string itemLabelText: ""
    property int itemLabelWidth: 120

    property string itemPlaceholder: ""

    property string itemText: ""
    property alias text: itemTextInput.text

    property bool isEditable: false

    property bool isEditing: false
    property bool isModified: false
    property bool isSelected: false

    signal textUpdated(string newText);
    signal dateUpdated(string newSQLDate);
    signal displayDatePickerAt(string field, int x, int y);
    signal displayRepeatPickerAt(string field, int x, int y);
    signal displayContextPickerAt(string contextType, int x, int y);
    signal displaySecurityLevelPickerAt(string field, int x, int y);
    signal contextAssignmentsUpdated();

    signal itemClicked();

    property Gradient backgroundGradient: Gradient {
        GradientStop { position: 0.0; color: "white" }
        GradientStop { position: 1.0; color: "#d9d9d9" }
    }

    Rectangle {
        id: background
        anchors.fill: parent
        //gradient: backgroundGradient
        color: "transparent"

        Text {
            id: itemLabel
            text: maincomponent.itemLabelText

            anchors.left: parent.left
            anchors.leftMargin: maincomponent.inputInset;
            width: maincomponent.itemLabelWidth

            visible: maincomponent.itemShowLabel

            anchors.verticalCenter: parent.verticalCenter

            font.pixelSize: 12
            font.family: "Lucida Grande"
            font.bold: true
            color: "#828282"

            horizontalAlignment: Text.AlignRight
            verticalAlignment: Text.AlignVCenter
        }

        Rectangle {
            id: inputRect

            anchors.top: parent.top
            anchors.topMargin: 0
            anchors.left: maincomponent.itemShowLabel ? itemLabel.right : parent.left
            anchors.leftMargin: maincomponent.inputInset
            anchors.right: parent.right
            anchors.rightMargin: maincomponent.inputInset
            anchors.bottom: parent.bottom
            anchors.bottomMargin: 0

            border.width: 1
            border.color: "lightsteelblue"

            Text {
                id: itemTextInputPlaceholder
                anchors.left: parent.left
                anchors.leftMargin: 2
                anchors.right: parent.right
                anchors.rightMargin: 2
                anchors.verticalCenter: parent.verticalCenter

                text: maincomponent.itemPlaceholder

                font.family: "Helvetica Neue"
                font.pixelSize: 12
                font.bold: false

                color: "#aaaaaa"

                visible: (itemTextInput.text.length === 0)
            }

            TextInput {
                id: itemTextInput

                property string defaultText: ""

                visible: false
                enabled: true
                text: maincomponent.itemText

                anchors.left: parent.left
                anchors.leftMargin: 2
                anchors.right: parent.right
                anchors.rightMargin: 2
                anchors.verticalCenter: parent.verticalCenter

                font.pixelSize: 12
                font.family: "Helvetica Neue"
                font.bold: false

                smooth: true
                clip: true
                color: "black"

                focus: visible ? maincomponent.focus : false

                selectByMouse: true
                selectionColor: "lightblue"

                onTextChanged: {
                    textUpdated(text);
                    maincomponent.isModified = true;
                }

                Keys.onEscapePressed: {
                    text = defaultText
                }

                Keys.onReturnPressed: {
                    //console.debug("Return pressed with " + defaultText)
                    if (defaultText !== text) {
                        textUpdated(text);
                    }

                    maincomponent.isEditing = false
                }

                onFocusChanged: {
                    //console.debug("Focus changed with " + defaultText)
                    //console.debug(focus)

                    if (focus) {
                        selectAll()

                    } else {
                        if (defaultText !== text) {
                            textUpdated(text);
                        }
                        maincomponent.isEditing = false
                    }
                }

                MouseArea {
                    anchors.fill: parent
                    visible: !itemTextInput.focus

                    onPressed: {
                        //console.debug("Date Picker requested in Line Input")
                        itemClicked();

                        itemTextInput.focus = true
                        itemTextInput.forceActiveFocus()
                    }
                }
            }

            Item {
                id: itemDateInput
                anchors.fill: parent

                Text {
                    id: itemDateInputPlaceholder
                    anchors.left: parent.left
                    anchors.leftMargin: 2
                    anchors.right: parent.right
                    anchors.rightMargin: itemDateInputPickerIcon.width + 4
                    anchors.verticalCenter: parent.verticalCenter

                    text: qsTr("Click to select date")

                    font.family: "Helvetica Neue"
                    font.pixelSize: 12
                    font.bold: false

                    color: "#aaaaaa"

                    visible: (maincomponent.itemText.length === 0)
                }

                Text {
                    id: itemDateInputText
                    anchors.left: parent.left
                    anchors.leftMargin: 2
                    anchors.right: parent.right
                    anchors.rightMargin: itemDateInputPickerIcon.width + 4
                    anchors.verticalCenter: parent.verticalCenter

                    text: maincomponent.itemText

                    font.family: "Helvetica Neue"
                    font.pixelSize: 12
                    font.bold: false

                    clip: true

                    color: "black"

                    visible: !(maincomponent.itemText.length === 0)
                }


                Image {
                    id: itemDateInputPickerIcon
                    anchors.right: parent.right
                    anchors.rightMargin: 2
                    anchors.verticalCenter: parent.verticalCenter

                    source: "qrc:/icons2/AIDelegate/PreviewIconCalendarButton12px.png"
                }

                MouseArea {
                    anchors.fill: parent

                    onPressed: {
                        console.debug("Date Picker requested in Line Input")
                        itemDateInputText.focus = true
                        displayDatePickerAt("review_dt", itemDateInputPickerIcon.x, itemDateInputPickerIcon.y)
                    }
                }
            }

            Item {
                id: itemContextInput
                anchors.fill: parent

                Text {
                    id: itemContextInputPlaceholder
                    anchors.left: parent.left
                    anchors.leftMargin: 2
                    anchors.right: parent.right
                    anchors.rightMargin: itemDateInputPickerIcon.width + 4
                    anchors.verticalCenter: parent.verticalCenter

                    text: qsTr("Click to select context")

                    font.family: "Helvetica Neue"
                    font.pixelSize: 12
                    font.bold: false

                    color: "#aaaaaa"

                    visible: (maincomponent.itemText.length === 0)
                }

                Text {
                    id: itemContextInputText
                    anchors.left: parent.left
                    anchors.leftMargin: 2
                    anchors.right: parent.right
                    anchors.rightMargin: itemDateInputPickerIcon.width + 4
                    anchors.verticalCenter: parent.verticalCenter

                    text: maincomponent.itemText

                    font.family: "Helvetica Neue"
                    font.pixelSize: 12
                    font.bold: false

                    clip: true

                    color: "black"

                    visible: !(maincomponent.itemText.length === 0)
                }


                Image {
                    id: itemContextInputPickerIcon
                    anchors.right: parent.right
                    anchors.rightMargin: 2
                    anchors.verticalCenter: parent.verticalCenter

                    source: {
                        if (maincomponent.contextInputType == "R") return "qrc:/icons2/AIDelegate/PreviewIconRACI_R_12px.png";
                        else if (maincomponent.contextInputType == "A") return "qrc:/icons2/AIDelegate/PreviewIconRACI_A_12px.png";
                        else if (maincomponent.contextInputType == "C") return "qrc:/icons2/AIDelegate/PreviewIconRACI_C_12px.png";
                        else if (maincomponent.contextInputType == "I") return "qrc:/icons2/AIDelegate/PreviewIconRACI_I_12px.png";
                        return "qrc:/icons2/AIDelegate/PreviewIconContext12px.png"
                    }
                }

                MouseArea {
                    anchors.fill: parent

                    onPressed: {
                        console.debug("Date Picker requested in Line Input")
                        itemContextInputText.focus = true
                        displayContextPickerAt(maincomponent.contextInputType, itemContextInputPickerIcon.x, itemContextInputPickerIcon.y)
                    }
                }
            }

            Item {
                id: itemSecurityLevelInput
                anchors.fill: parent

                Text {
                    id: itemSecurityLevelInputPlaceholder
                    anchors.left: parent.left
                    anchors.leftMargin: 2
                    anchors.right: parent.right
                    anchors.rightMargin: itemDateInputPickerIcon.width + 4
                    anchors.verticalCenter: parent.verticalCenter

                    text: qsTr("Click to select security level")

                    font.family: "Helvetica Neue"
                    font.pixelSize: 12
                    font.bold: false

                    color: "#aaaaaa"

                    visible: (maincomponent.itemText.length === 0)
                }

                Text {
                    id: itemSecurityLevelInputText
                    anchors.left: parent.left
                    anchors.leftMargin: 2
                    anchors.right: parent.right
                    anchors.rightMargin: itemDateInputPickerIcon.width + 4
                    anchors.verticalCenter: parent.verticalCenter

                    text: maincomponent.itemText

                    font.family: "Helvetica Neue"
                    font.pixelSize: 12
                    font.bold: false

                    clip: true

                    color: "black"

                    visible: !(maincomponent.itemText.length === 0)
                }


                Image {
                    id: itemSecurityLevelInputPickerIcon
                    anchors.right: parent.right
                    anchors.rightMargin: 2
                    anchors.verticalCenter: parent.verticalCenter

                    source: "qrc:/icons2/AIDelegate/PreviewLockButton16px.png"
                }

                MouseArea {
                    anchors.fill: parent

                    onPressed: {
                        console.debug("Security Picker requested in Line Input")
                        itemSecurityLevelInputText.focus = true
                        displaySecurityLevelPickerAt("protectionlevel", itemSecurityLevelInputPickerIcon.x, itemSecurityLevelInputPickerIcon.y)
                    }
                }
            }

            Item {
                id: itemRepeatInput
                anchors.fill: parent

                Text {
                    id: itemRepeatInputPlaceholder
                    anchors.left: parent.left
                    anchors.leftMargin: 2
                    anchors.right: parent.right
                    anchors.rightMargin: itemRepeatInputPickerIcon.width + 4
                    anchors.verticalCenter: parent.verticalCenter

                    text: qsTr("Click to select repetition")

                    font.family: "Helvetica Neue"
                    font.pixelSize: 12
                    font.bold: false

                    color: "#aaaaaa"

                    visible: (maincomponent.itemText.length === 0)
                }

                Text {
                    id: itemRepeatInputText
                    anchors.left: parent.left
                    anchors.leftMargin: 2
                    anchors.right: parent.right
                    anchors.rightMargin: itemRepeatInputPickerIcon.width + 4
                    anchors.verticalCenter: parent.verticalCenter

                    text: maincomponent.itemText

                    font.family: "Helvetica Neue"
                    font.pixelSize: 12
                    font.bold: false

                    clip: true

                    color: "black"

                    visible: !(maincomponent.itemText.length === 0)
                }


                Image {
                    id: itemRepeatInputPickerIcon
                    anchors.right: parent.right
                    anchors.rightMargin: 0
                    anchors.verticalCenter: parent.verticalCenter

                    source: "qrc:/icons2/AIDelegate/PreviewRepeatButton16px.png"
                }

                MouseArea {
                    anchors.fill: parent

                    onPressed: {
                        console.debug("Repeat Picker requested in Line Input")
                        itemRepeatInputText.focus = true
                        displayRepeatPickerAt("repeat", itemRepeatInputPickerIcon.x, itemRepeatInputPickerIcon.y)
                    }
                }
            }

        }
    }

    Component.onCompleted: {
        if (lineInputType == 0) {
            itemTextInput.visible = true
            itemDateInput.visible = false
            itemContextInput.visible = false
            itemSecurityLevelInput.visible = false
            itemRepeatInput.visible = false

        } else if (lineInputType == 1) {
            itemTextInput.visible = false
            itemDateInput.visible = true
            itemContextInput.visible = false
            itemSecurityLevelInput.visible = false
            itemRepeatInput.visible = false

        } else if (lineInputType == 2) {
            itemTextInput.visible = false
            itemDateInput.visible = false
            itemContextInput.visible = true
            itemSecurityLevelInput.visible = false
            itemRepeatInput.visible = false

        } else if (lineInputType == 3) {
            itemTextInput.visible = false
            itemDateInput.visible = false
            itemContextInput.visible = false
            itemSecurityLevelInput.visible = true
            itemRepeatInput.visible = false

        } else if (lineInputType == 4) {
            itemTextInput.visible = false
            itemDateInput.visible = false
            itemContextInput.visible = false
            itemSecurityLevelInput.visible = false
            itemRepeatInput.visible = true
        }
    }

}
